﻿using Amazon;
using Amazon.SecretsManager;
using Amazon.SecretsManager.Extensions.Caching;

namespace MySecretsManagerCacheApp;

public static class Program {
    public static async Task Main(string[] args) {
        string secretId = "my-credentials";

        IAmazonSecretsManager client = new AmazonSecretsManagerClient(RegionEndpoint.USEast1); // us-east-1
        
        SecretCacheConfiguration cacheConfiguration = new SecretCacheConfiguration
        {
            CacheItemTTL = 20000, // 20 seconds
            VersionStage = "AWSCURRENT",
        };

        SecretsManagerCache cache = new SecretsManagerCache(client, cacheConfiguration);

        Console.WriteLine($"First request {await cache.GetSecretString(secretId).ConfigureAwait(false)}");
        Console.WriteLine("Disconnect your computer from the internet, and press any key...");
        Console.ReadKey();
        Console.WriteLine($"Second request {await cache.GetSecretString(secretId).ConfigureAwait(false)}");
    }
    
    private static async Task<string> GetSecretValue(SecretsManagerCache cache, string secretName, string region)
    {
        try
        {
            var x = cache.GetCachedSecret(secretName);
            Console.WriteLine(await cache.GetSecretString(secretName).ConfigureAwait(false));
        
            var response = await cache.GetSecretString(secretName).ConfigureAwait(false);
            
            return response;
        }
        catch (OperationCanceledException oce)
        {
            System.Console.WriteLine($"Request timed out, the cancellation token was triggered. {oce.Message}");
            throw;
        }
        catch (Exception ex)
        {
            Console.Error.WriteLine("Error: " + ex.Message);
            throw;
        }
    }
}